import { IObservable, IObserver } from "./Observable";
import { Option } from "./Option";
import { IDisposable } from "./Util";
export declare type Delegate<T> = (x: T) => void;
export declare type DotNetDelegate<T> = (sender: any, x: T) => void;
export interface IDelegateEvent<T> {
    AddHandler(d: DotNetDelegate<T>): void;
    RemoveHandler(d: DotNetDelegate<T>): void;
}
export interface IEvent<T> extends IObservable<T>, IDelegateEvent<T> {
    Publish: IEvent<T>;
    Trigger(x: T): void;
}
export default class Event<T> implements IEvent<T> {
    delegates: Array<Delegate<T>>;
    private _subscriber?;
    private _dotnetDelegates?;
    constructor(_subscriber?: (o: IObserver<T>) => IDisposable, delegates?: any[]);
    Add(f: Delegate<T>): void;
    get Publish(): this;
    Trigger(value: T): void;
    AddHandler(handler: DotNetDelegate<T>): void;
    RemoveHandler(handler: DotNetDelegate<T>): void;
    Subscribe(arg: IObserver<T> | Delegate<T>): IDisposable;
    private _addHandler;
    private _removeHandler;
    private _subscribeFromObserver;
    private _subscribeFromCallback;
}
export declare function add<T>(callback: (x: T) => void, sourceEvent: IEvent<T>): void;
export declare function choose<T, U>(chooser: (x: T) => Option<U>, sourceEvent: IEvent<T>): IEvent<U>;
export declare function filter<T>(predicate: (x: T) => boolean, sourceEvent: IEvent<T>): IEvent<T>;
export declare function map<T, U>(mapping: (x: T) => U, sourceEvent: IEvent<T>): IEvent<U>;
export declare function merge<T>(event1: IEvent<T>, event2: IEvent<T>): IEvent<T>;
export declare function pairwise<T>(sourceEvent: IEvent<T>): IEvent<[T, T]>;
export declare function partition<T>(predicate: (x: T) => boolean, sourceEvent: IEvent<T>): IEvent<T>[];
export declare function scan<U, T>(collector: (u: U, t: T) => U, state: U, sourceEvent: IEvent<T>): IEvent<U>;
export declare function split<T, _U1, _U2>(splitter: (x: T) => any, sourceEvent: IEvent<T>): IEvent<unknown>[];
