import { IDisposable } from "./Util";
export interface IObserver<T> {
    OnNext: (x: T) => void;
    OnError: (e: any) => void;
    OnCompleted: () => void;
}
export declare class Observer<T> implements IObserver<T> {
    OnNext: (x: T) => void;
    OnError: (e: any) => void;
    OnCompleted: () => void;
    constructor(onNext: (x: T) => void, onError?: (e: any) => void, onCompleted?: () => void);
}
export interface IObservable<T> {
    Subscribe: (o: IObserver<T>) => IDisposable;
}
export declare function protect<T>(f: () => T, succeed: (x: T) => void, fail: (e: any) => void): void;
export declare function add<T>(callback: (x: T) => void, source: IObservable<T>): void;
export declare function choose<T, U>(chooser: (x: T) => U, source: IObservable<T>): IObservable<U>;
export declare function filter<T>(predicate: (x: T) => boolean, source: IObservable<T>): IObservable<T | null>;
export declare function map<T, U>(mapping: (x: T) => U, source: IObservable<T>): IObservable<U>;
export declare function merge<T>(source1: IObservable<T>, source2: IObservable<T>): IObservable<T>;
export declare function pairwise<T>(source: IObservable<T>): IObservable<[T, T]>;
export declare function partition<T>(predicate: (x: T) => boolean, source: IObservable<T>): IObservable<T | null>[];
export declare function scan<U, T>(collector: (u: U, t: T) => U, state: U, source: IObservable<T>): IObservable<U>;
export declare function split<T, _U1, _U2>(splitter: (x: T) => any, source: IObservable<T>): IObservable<unknown>[];
export declare function subscribe<T>(callback: (x: T) => void, source: IObservable<T>): IDisposable;
