export declare type FieldInfo = [string, TypeInfo];
export declare type Constructor = new (...args: any[]) => any;
export declare class CaseInfo {
    declaringType: TypeInfo;
    tag: number;
    name: string;
    fields?: TypeInfo[] | undefined;
    constructor(declaringType: TypeInfo, tag: number, name: string, fields?: TypeInfo[] | undefined);
}
export declare type EnumCase = [string, number];
export declare class TypeInfo {
    fullname: string;
    generics?: TypeInfo[] | undefined;
    constructor?: Constructor | undefined;
    fields?: (() => FieldInfo[]) | undefined;
    cases?: (() => CaseInfo[]) | undefined;
    enumCases?: EnumCase[] | undefined;
    constructor(fullname: string, generics?: TypeInfo[] | undefined, constructor?: Constructor | undefined, fields?: (() => FieldInfo[]) | undefined, cases?: (() => CaseInfo[]) | undefined, enumCases?: EnumCase[] | undefined);
    toString(): string;
    Equals(other: TypeInfo): boolean;
    CompareTo(other: TypeInfo): number;
}
export declare function getGenerics(t: TypeInfo): TypeInfo[];
export declare function equals(t1: TypeInfo, t2: TypeInfo): boolean;
export declare function compare(t1: TypeInfo, t2: TypeInfo): number;
export declare function type(fullname: string, generics?: TypeInfo[]): TypeInfo;
export declare function record(fullname: string, generics: TypeInfo[], constructor: Constructor, fields: () => FieldInfo[]): TypeInfo;
export declare function anonRecord(...fields: FieldInfo[]): TypeInfo;
export declare type CaseInfoInput = string | [string, TypeInfo[]];
export declare function union(fullname: string, generics: TypeInfo[], constructor: Constructor, cases: () => CaseInfoInput[]): TypeInfo;
export declare function tuple(...generics: TypeInfo[]): TypeInfo;
export declare function delegate(...generics: TypeInfo[]): TypeInfo;
export declare function lambda(argType: TypeInfo, returnType: TypeInfo): TypeInfo;
export declare function option(generic: TypeInfo): TypeInfo;
export declare function list(generic: TypeInfo): TypeInfo;
export declare function array(generic: TypeInfo): TypeInfo;
export declare function enumType(fullname: string, underlyingType: TypeInfo, enumCases: EnumCase[]): TypeInfo;
export declare const obj: TypeInfo;
export declare const unit: TypeInfo;
export declare const char: TypeInfo;
export declare const string: TypeInfo;
export declare const bool: TypeInfo;
export declare const int8: TypeInfo;
export declare const uint8: TypeInfo;
export declare const int16: TypeInfo;
export declare const uint16: TypeInfo;
export declare const int32: TypeInfo;
export declare const uint32: TypeInfo;
export declare const float32: TypeInfo;
export declare const float64: TypeInfo;
export declare const decimal: TypeInfo;
export declare function name(info: FieldInfo | CaseInfo | TypeInfo): string;
export declare function fullName(t: TypeInfo): string;
export declare function namespace(t: TypeInfo): string;
export declare function isArray(t: TypeInfo): boolean;
export declare function getElementType(t: TypeInfo): TypeInfo | undefined;
export declare function isGenericType(t: TypeInfo): boolean;
export declare function isEnum(t: TypeInfo): boolean;
/**
 * This doesn't replace types for fields (records) or cases (unions)
 * but it should be enough for type comparison purposes
 */
export declare function getGenericTypeDefinition(t: TypeInfo): TypeInfo;
export declare function getEnumUnderlyingType(t: TypeInfo): TypeInfo | undefined;
export declare function getEnumValues(t: TypeInfo): number[];
export declare function getEnumNames(t: TypeInfo): string[];
export declare function parseEnum(t: TypeInfo, str: string): number;
export declare function tryParseEnum(t: TypeInfo, str: string): [boolean, number];
export declare function getEnumName(t: TypeInfo, v: number): string;
export declare function isEnumDefined(t: TypeInfo, v: string | number): boolean;
export declare function getUnionCases(t: TypeInfo): CaseInfo[];
export declare function getRecordElements(t: TypeInfo): FieldInfo[];
export declare function getTupleElements(t: TypeInfo): TypeInfo[];
export declare function getFunctionElements(t: TypeInfo): [TypeInfo, TypeInfo];
export declare function isUnion(t: any): boolean;
export declare function isRecord(t: any): boolean;
export declare function isTuple(t: TypeInfo): boolean;
export declare function isFunction(t: TypeInfo): boolean;
export declare function getUnionFields(v: any, t: TypeInfo): [CaseInfo, any[]];
export declare function getUnionCaseFields(uci: CaseInfo): FieldInfo[];
export declare function getRecordFields(v: any): any[];
export declare function getRecordField(v: any, field: FieldInfo): any;
export declare function getTupleFields(v: any): any[];
export declare function getTupleField(v: any, i: number): any;
export declare function makeUnion(uci: CaseInfo, values: any[]): any;
export declare function makeRecord(t: TypeInfo, values: any[]): any;
export declare function makeTuple(values: any[], _t: TypeInfo): any;
export declare function getCaseTag(x: any): number;
export declare function getCaseName(x: any): string;
export declare function getCaseFields(x: any): any[];
