import Decimal from "./Decimal";
import Long from "./Long";
import { Option } from "./Option";
import { IComparer, IDisposable } from "./Util";
export interface IEnumerator<T> {
    Current: T | undefined;
    MoveNext(): boolean;
}
export interface IEnumerable<T> {
    GetEnumerator(): IEnumerator<T>;
}
interface IGenericAdder<T> {
    GetZero(): T;
    Add(x: T, y: T): T;
}
interface IGenericAverager<T> {
    GetZero(): T;
    Add(x: T, y: T): T;
    DivideByInt(x: T, i: number): T;
}
export declare class Enumerator<T> implements IEnumerator<T> {
    private iter;
    private current?;
    constructor(iter: Iterator<T>);
    MoveNext(): boolean;
    get Current(): T | undefined;
    Reset(): void;
    Dispose(): void;
}
export declare function getEnumerator<T>(o: any): IEnumerator<T>;
export declare function toIterator<T>(en: IEnumerator<T>): {
    next(): {
        done: boolean;
        value: T | undefined;
    } | {
        done: boolean;
        value: null;
    };
};
export declare function ofArray<T>(xs: ArrayLike<T>): Iterable<T>;
export declare function allPairs<T1, T2>(xs: Iterable<T1>, ys: Iterable<T2>): Iterable<[T1, T2]>;
export declare function append<T>(xs: Iterable<T>, ys: Iterable<T>): Iterable<T>;
export declare function average<T>(xs: Iterable<T>, averager: IGenericAverager<T>): T;
export declare function averageBy<T, T2>(f: (a: T) => T2, xs: Iterable<T>, averager: IGenericAverager<T2>): T2;
export declare function concat<T>(xs: Iterable<Iterable<T>>): Iterable<T>;
export declare function collect<T, U>(f: (x: T) => Iterable<U>, xs: Iterable<T>): Iterable<U>;
export declare function choose<T, U>(f: (x: T) => U, xs: Iterable<T>): Iterable<U | null>;
export declare function compareWith<T>(f: (x: T, y: T) => number, xs: Iterable<T>, ys: Iterable<T>): number | null;
export declare function delay<T>(f: () => Iterable<T>): Iterable<T>;
export declare function empty<T>(): Iterable<T>;
export declare function enumerateFromFunctions<T, Enumerator>(factory: () => Enumerator, moveNext: (e: Enumerator) => boolean, current: (e: Enumerator) => T): Iterable<T>;
export declare function enumerateWhile<T>(cond: () => boolean, xs: Iterable<T>): Iterable<T>;
export declare function enumerateThenFinally<T>(xs: Iterable<T>, finalFn: () => void): Iterable<T>;
export declare function enumerateUsing<T extends IDisposable, U>(disp: T, work: (x: T) => Iterable<U>): Iterable<U> | undefined;
export declare function exactlyOne<T>(xs: Iterable<T>): T;
export declare function except<T>(itemsToExclude: Iterable<T>, source: Iterable<T>): Iterable<T>;
export declare function exists<T>(f: (x: T) => boolean, xs: Iterable<T>): boolean;
export declare function exists2<T1, T2>(f: (x: T1, y: T2) => boolean, xs: Iterable<T1>, ys: Iterable<T2>): boolean;
export declare function forAll<T>(f: (x: T) => boolean, xs: Iterable<T>): boolean;
export declare function forAll2<T1, T2>(f: (x: T1, y: T2) => boolean, xs: Iterable<T1>, ys: Iterable<T2>): boolean;
export declare function contains<T>(i: T, xs: Iterable<T>): boolean;
export declare function filter<T>(f: (x: T) => boolean, xs: Iterable<T>): Iterable<T>;
export declare function where<T>(f: (x: T) => boolean, xs: Iterable<T>): Iterable<T>;
export declare function fold<T, ST>(f: (acc: ST, x: T, i?: number) => ST, acc: ST, xs: Iterable<T>): ST;
export declare function foldBack<T, ST>(f: (x: T, acc: ST, i?: number) => ST, xs: Iterable<T>, acc: ST): ST;
export declare function fold2<T1, T2, ST>(f: (acc: ST, x: T1, y: T2, i?: number) => ST, acc: ST, xs: Iterable<T1>, ys: Iterable<T2>): ST;
export declare function foldBack2<T1, T2, ST>(f: (x: T1, y: T2, acc: ST, i?: number) => ST, xs: Iterable<T1>, ys: Iterable<T2>, acc: ST): ST;
export declare function tryHead<T>(xs: Iterable<T>): Option<T>;
export declare function head<T>(xs: Iterable<T>): T | null;
export declare function initialize<T>(n: number, f: (i: number) => T): Iterable<T>;
export declare function initializeInfinite<T>(f: (i: number) => T): Iterable<T>;
export declare function tryItem<T>(i: number, xs: Iterable<T>): Option<T>;
export declare function item<T>(i: number, xs: Iterable<T>): T | null;
export declare function iterate<T>(f: (x: T) => void, xs: Iterable<T>): void;
export declare function iterate2<T1, T2>(f: (x: T1, y: T2) => void, xs: Iterable<T1>, ys: Iterable<T2>): void;
export declare function iterateIndexed<T>(f: (i: number, x: T) => void, xs: Iterable<T>): void;
export declare function iterateIndexed2<T1, T2>(f: (i: number, x: T1, y: T2) => void, xs: Iterable<T1>, ys: Iterable<T2>): void;
export declare function isEmpty<T>(xs: Iterable<T>): boolean | undefined;
export declare function tryLast<T>(xs: Iterable<T>): Option<T>;
export declare function last<T>(xs: Iterable<T>): T | null;
export declare function length<T>(xs: Iterable<T>): number;
export declare function map<T, U>(f: (x: T) => U, xs: Iterable<T>): Iterable<U>;
export declare function mapIndexed<T, U>(f: (i: number, x: T) => U, xs: Iterable<T>): Iterable<U>;
export declare function indexed<T>(xs: Iterable<T>): Iterable<[number, T]>;
export declare function map2<T1, T2, U>(f: (x: T1, y: T2) => U, xs: Iterable<T1>, ys: Iterable<T2>): Iterable<U>;
export declare function mapIndexed2<T1, T2, U>(f: (i: number, x: T1, y: T2) => U, xs: Iterable<T1>, ys: Iterable<T2>): Iterable<U>;
export declare function map3<T1, T2, T3, U>(f: (x: T1, y: T2, z: T3) => U, xs: Iterable<T1>, ys: Iterable<T2>, zs: Iterable<T3>): Iterable<U>;
export declare function mapFold<T, ST, R>(f: (acc: ST, x: T) => [R, ST], acc: ST, xs: Iterable<T>, transform?: (r: Iterable<R>) => Iterable<R>): [Iterable<R>, ST];
export declare function mapFoldBack<T, ST, R>(f: (x: T, acc: ST) => [R, ST], xs: Iterable<T>, acc: ST, transform?: (r: Iterable<R>) => Iterable<R>): [Iterable<R>, ST];
export declare function max<T extends number>(xs: Iterable<T>, comparer?: IComparer<T>): T;
export declare function maxBy<T, U extends number>(f: (x: T) => U, xs: Iterable<T>, comparer?: IComparer<U>): T;
export declare function min<T extends number>(xs: Iterable<T>, comparer?: IComparer<T>): T;
export declare function minBy<T, U extends number>(f: (x: T) => U, xs: Iterable<T>, comparer?: IComparer<U>): T;
export declare function pairwise<T extends number>(xs: Iterable<T>): Iterable<number[]>;
export declare function rangeChar(first: string, last: string): Iterable<string>;
export declare function rangeLong(first: Long, step: Long, last: Long, unsigned: boolean): Iterable<Long>;
export declare function rangeDecimal(first: Decimal, step: Decimal, last: Decimal): Iterable<Decimal>;
export declare function rangeNumber(first: number, step: number, last: number): Iterable<number>;
export declare function readOnly<T>(xs: Iterable<T>): Iterable<T>;
export declare function reduce<T>(f: (acc: T, x: T) => T, xs: Iterable<T>): T;
export declare function reduceBack<T>(f: (acc: T, x: T, i?: number) => T, xs: Iterable<T>): T;
export declare function replicate<T>(n: number, x: T): Iterable<T>;
export declare function reverse<T>(xs: Iterable<T>): Iterable<T>;
export declare function scan<T, ST>(f: (st: ST, x: T) => ST, seed: ST, xs: Iterable<T>): Iterable<ST>;
export declare function scanBack<T, ST>(f: (x: T, st: ST) => ST, xs: Iterable<T>, seed: ST): Iterable<ST>;
export declare function singleton<T>(y: T): Iterable<T>;
export declare function skip<T>(n: number, xs: Iterable<T>): Iterable<T>;
export declare function skipWhile<T>(f: (x: T) => boolean, xs: Iterable<T>): Iterable<T>;
export declare function sortWith<T>(f: (x: T, y: T) => number, xs: Iterable<T>): Iterable<T>;
export declare function sum<T>(xs: Iterable<T>, adder: IGenericAdder<T>): T;
export declare function sumBy<T, T2>(f: (x: T) => T2, xs: Iterable<T>, adder: IGenericAdder<T2>): T2;
export declare function tail<T>(xs: Iterable<T>): Iterable<T>;
export declare function take<T>(n: number, xs: Iterable<T>, truncate?: boolean): Iterable<T>;
export declare function truncate<T>(n: number, xs: Iterable<T>): Iterable<T>;
export declare function takeWhile<T>(f: (x: T) => boolean, xs: Iterable<T>): Iterable<T>;
export declare function tryFind<T>(f: (x: T, i?: number) => boolean, xs: Iterable<T>, defaultValue?: T): Option<T>;
export declare function find<T>(f: (x: T, i?: number) => boolean, xs: Iterable<T>): T | null;
export declare function tryFindBack<T>(f: (x: T, i?: number) => boolean, xs: Iterable<T>, defaultValue?: T): Option<T>;
export declare function findBack<T>(f: (x: T, i?: number) => boolean, xs: Iterable<T>): T | null;
export declare function tryFindIndex<T>(f: (x: T, i?: number) => boolean, xs: Iterable<T>): Option<number>;
export declare function findIndex<T>(f: (x: T, i?: number) => boolean, xs: Iterable<T>): number | null;
export declare function tryFindIndexBack<T>(f: (x: T, i?: number) => boolean, xs: Iterable<T>): Option<number>;
export declare function findIndexBack<T>(f: (x: T, i?: number) => boolean, xs: Iterable<T>): number | null;
export declare function tryPick<T, U>(f: (x: T, i?: number) => Option<U>, xs: Iterable<T>): Option<U>;
export declare function pick<T, U>(f: (x: T, i?: number) => Option<U>, xs: Iterable<T>): U | null;
export declare function unfold<T, ST>(f: (st: ST) => Option<[T, ST]>, fst: ST): Iterable<T>;
export declare function zip<T1, T2>(xs: Iterable<T1>, ys: Iterable<T2>): Iterable<(T1 | T2)[]>;
export declare function zip3<T1, T2, T3>(xs: Iterable<T1>, ys: Iterable<T2>, zs: Iterable<T3>): Iterable<(T1 | T2 | T3)[]>;
export declare function windowed<T>(windowSize: number, source: Iterable<T>): Iterable<T[]>;
export declare function transpose<T>(source: Iterable<Iterable<T>>): Iterable<Iterable<T>>;
export {};
