export declare function extend(target: any, ...sources: any[]): any;
export declare const enum DateKind {
    Unspecified = 0,
    UTC = 1,
    Local = 2
}
export interface IDateTime extends Date {
    kind?: DateKind;
}
export interface IDateTimeOffset extends Date {
    offset?: number;
}
export interface IComparer<T> {
    Compare(x: T, y: T): number;
}
export interface IComparable<T> {
    CompareTo(x: T): number;
}
export interface IEqualityComparer<T> {
    Equals(x: T, y: T): boolean;
    GetHashCode(x: T): number;
}
export interface IEquatable<T> {
    Equals(x: T): boolean;
}
export interface IHashable {
    GetHashCode(): number;
}
export interface IDisposable {
    Dispose(): void;
}
export declare function isIterable<T>(x: T | Iterable<T>): x is Iterable<T>;
export declare function isArrayLike<T>(x: T | ArrayLike<T>): x is ArrayLike<T>;
export declare function isComparer<T>(x: T | IComparer<T>): x is IComparer<T>;
export declare function isComparable<T>(x: T | IComparable<T>): x is IComparable<T>;
export declare function isEquatable<T>(x: T | IEquatable<T>): x is IEquatable<T>;
export declare function isHashable<T>(x: T | IHashable): x is IHashable;
export declare function isDisposable<T>(x: T | IDisposable): x is IDisposable;
export declare class Comparer<T> implements IComparer<T> {
    Compare: (x: T, y: T) => number;
    constructor(f?: (x: T, y: T) => number);
}
export declare function comparerFromEqualityComparer<T>(comparer: IEqualityComparer<T>): IComparer<T>;
export declare function containsValue<K, V>(v: V, map: Map<K, V>): boolean;
export declare function tryGetValue<K, V>(map: Map<K, V>, key: K, defaultValue: V): [boolean, V | undefined];
export declare function addToSet<T>(v: T, set: Set<T>): boolean;
export declare function assertEqual<T>(actual: T, expected: T, msg?: string): void;
export declare function assertNotEqual<T>(actual: T, expected: T, msg?: string): void;
export declare class Lazy<T> {
    factory: () => T;
    isValueCreated: boolean;
    private createdValue?;
    constructor(factory: () => T);
    get Value(): T | undefined;
    get IsValueCreated(): boolean;
}
export declare function lazyFromValue<T>(v: T): Lazy<T>;
export declare function padWithZeros(i: number, length: number): string;
export declare function padLeftAndRightWithZeros(i: number, lengthLeft: number, lengthRight: number): string;
export declare function dateOffset(date: IDateTime | IDateTimeOffset): number;
export declare function int16ToString(i: number, radix?: number): string;
export declare function int32ToString(i: number, radix?: number): string;
export declare abstract class ObjectRef {
    static id(o: any): any;
    private static idMap;
    private static count;
}
export declare function stringHash(s: string): number;
export declare function numberHash(x: number): number;
export declare function combineHashCodes(hashes: number[]): number;
export declare function identityHash<T>(x: T): number;
export declare function structuralHash<T>(x: T): number;
export declare function equalArraysWith<T>(x: ArrayLike<T>, y: ArrayLike<T>, eq: (x: T, y: T) => boolean): boolean;
export declare function equalArrays<T>(x: ArrayLike<T>, y: ArrayLike<T>): boolean;
export declare function equals<T>(x: T, y: T): boolean;
export declare function compareDates(x: Date | IDateTime | IDateTimeOffset, y: Date | IDateTime | IDateTimeOffset): 1 | 0 | -1;
export declare function comparePrimitives(x: any, y: any): number;
export declare function compareArraysWith<T>(x: ArrayLike<T>, y: ArrayLike<T>, comp: (x: T, y: T) => number): number;
export declare function compareArrays<T>(x: ArrayLike<T>, y: ArrayLike<T>): number;
export declare function compareObjects(x: {
    [k: string]: any;
}, y: {
    [k: string]: any;
}): number;
export declare function compare<T>(x: T, y: T): number;
export declare function min<T>(comparer: (x: T, y: T) => number, x: T, y: T): T;
export declare function max<T>(comparer: (x: T, y: T) => number, x: T, y: T): T;
export declare function createAtom<T>(value: T): (v?: T) => T | void;
export declare function createObj(fields: Iterable<any>, caseRule?: number): {
    [k: string]: any;
};
export declare function jsOptions(mutator: (x: object) => void): object;
export declare function round(value: number, digits?: number): number;
export declare function sign(x: number): number;
export declare function randomNext(min: number, max: number): number;
export declare function randomBytes(buffer: Uint8Array): void;
export declare function unescapeDataString(s: string): string;
export declare function escapeDataString(s: string): string;
export declare function escapeUriString(s: string): string;
export declare function count<T>(col: Iterable<T>): number;
export declare function clear<T>(col: Iterable<T>): void;
export declare function uncurry(arity: number, f: Function): Function | null;
export declare function curry(arity: number, f: Function): Function | undefined;
export declare function partialApply(arity: number, f: Function, args: any[]): any;
declare type CurriedArgMapping = [number, number] | 0;
export declare function mapCurriedArgs(fn: Function, mappings: CurriedArgMapping[]): (arg: any) => any;
export declare function addToDict<K, V>(dict: Map<K, V>, k: K, v: V): void;
export declare function getItemFromDict<K, V>(map: Map<K, V>, key: K): V | undefined;
export {};
